@@ -1,7 +1,7 @@
 ;;; jde-javadoc.el --- JDE javadoc autodoc
-;; $Revision: 1.3 $
+;; $Revision: 1.5 $
 
-;; Copyright (C) 1998, 2000, 2001 by David Ponce
+;; Copyright (C) 1998, 2000, 2001, 2002 by David Ponce
 
 ;; Author: David Ponce <david@dponce.com>
 ;; Maintainer: David Ponce <david@dponce.com>
@@ -36,9 +36,15 @@
 ;; See at end of this file.
 
 ;;; Code:
+(provide 'jde-javadoc)
+
 (require 'tempo)
 (require 'semantic-java)
 
+(eval-when-compile
+  (require 'jde)
+  (require 'jde-parse))
+
 ;;;; Customization
 ;;;; -------------
 
@@ -317,6 +323,29 @@ That is strip any array brackets from NAME."
       (match-string 1 name)
     name))
 
+(defcustom jde-javadoc-check-undeclared-exception-flag nil
+  "*non-nil means to check for undeclared exceptions.
+When an exception is implicitly declared (inherits from
+RuntimeException) any associated @exception/@throws tag that already
+exists will be just kept without issuing a warning.  Other extra tags
+are automatically removed.
+
+If nil extra @exception/@throws tags are never removed but warnings
+are issued for (maybe) undeclared exceptions."
+  :group 'jde-javadoc
+  :type 'boolean)
+
+(defun jde-javadoc-implicit-exception-p (type)
+  "Return non-nil if TYPE is an implicitly declared exception.
+That is if TYPE inherits from java.lang.RuntimeException or if Java
+reflection failed to process TYPE."
+  (condition-case nil
+      (jde-jeval-r
+       (format "jde.util.Completion.isAncestorOf(%S,%S);"
+               "java.lang.RuntimeException"
+               (jde-parse-get-qualified-name type)))
+    (error t)))
+
 ;;;; Text helpers
 ;;;; ------------
 
@@ -419,7 +448,8 @@ WITH-KEY is 'ref VALUE-KEY is a normalized VALUE-STRING reference (see
       (cond ((eq with-key 'name)
              (setq key (and (string-match
                              "[* \n\r\t]*\\([^ \n\r\t]+\\)" tag-val)
-                            (match-string 1 tag-val))))
+                            (jde-javadoc-variable-name
+                             (match-string 1 tag-val)))))
             ((eq with-key 'ref)
              (setq key (jde-javadoc-normalize-ref tag-val))))
       (setq tag-list (cons (cons tag-val key) tag-list)))
@@ -972,6 +1002,8 @@ errors were found."
       (jde-javadoc-dynamic-status)
       (setq item (cdr (car args)))
       (or (member item items)
+          (and jde-javadoc-check-undeclared-exception-flag
+               (jde-javadoc-implicit-exception-p item))
           (setq report
                 (cons
                  (format
@@ -1358,8 +1390,10 @@ one for each exception in TYPES."
       (jde-javadoc-dynamic-status)
       (setq type (cdr type))
       (or (member type types)
-          (jde-javadoc-insert-previous-tag
-           doctree "exception" type))))
+          (if (or (not jde-javadoc-check-undeclared-exception-flag)
+                  (jde-javadoc-implicit-exception-p type))
+              (jde-javadoc-insert-previous-tag
+               doctree "exception" type)))))
    (jde-javadoc-doctree-tag doctree "exception")))
 
 (defun jde-javadoc-insert-return-tag (doctree type)
@@ -1570,9 +1604,15 @@ NOCONFIRM is non-nil."
 
 (defun jde-javadoc-nonterminal-at-line (&optional checkcache)
   "Search the bovine table for the token at the current line.
-If the optional argument CHECKCACHE is non-nil, then reparse the
-buffer if needed."
-  (semantic-bovinate-toplevel checkcache)
+Call `semantic-bovinate-toplevel' with optional argument CHECKCACHE."
+  (save-excursion
+    ;; Preserve current tokens when the lexer fails (when there is an
+    ;; unclosed block or an unterminated string for example).
+    (let ((semantic-flex-unterminated-syntax-end-function
+           #'(lambda (syntax &rest ignore)
+               (throw 'jde-javadoc-flex-error syntax))))
+      (catch 'jde-javadoc-flex-error
+        (semantic-bovinate-toplevel checkcache))))
   (save-excursion
     ;; Move the point to the first non-blank character found.  Skip
     ;; spaces, tabs and newlines.
@@ -1828,12 +1868,30 @@ definition."
                            (point))))
            (and (>= p start) (<= p end))))))
 
-(provide 'jde-javadoc)
-
 ;;
 ;; $Log: jde-javadoc.el,v $
-;; Revision 1.3  2001/08/16 03:29:20  andyp
-;; Update to JDE 2.2.7.1
+;; Revision 1.5  2002/09/14 03:21:01  andyp
+;; sync to jde 2.2.9beta12
+;;
+;; Revision 1.22  2002/06/23 17:37:36  jslopez
+;; Removes carriage returns.
+;;
+;; Revision 1.21  2002/06/22 06:25:26  paulk
+;; Adds jde-javadoc-check-undeclared-exception-flag option. Thanks to David Ponce.
+;;
+;; Revision 1.20  2001/12/14 03:17:50  paulk
+;; jde-javadoc-nonterminal-at-line preserves current tokens when the
+;; lexer fails (when there is an unclosed block or an unterminated
+;; string for example). This enhancement works only with semantic 1.4
+;; beta 13 (and above). With older versions
+;; jde-javadoc-nonterminal-at-line continues to work as previously.
+;; Thanks to David Ponce.
+;;
+;; Revision 1.19  2001/08/06 05:25:21  paulk
+;; jde-javadoc-parse-tag-values now removes the brackets from
+;; VALUE-STRING when VALUE-KEY is 'name.  This fixes checker error when
+;; it tries to match an array name in javadoc comments and in argument
+;; list. Thanks to David Ponce.
 ;;
 ;; Revision 1.18  2001/05/19 02:36:00  paulk
 ;; Updated to support semantic 1.4. Thanks to David Ponce.
