@@ -1,11 +1,11 @@
 ;;; jde-make.el -- Integrated Development Environment for Java.
-;; $Revision: 1.3 $ 
+;; $Revision: 1.5 $ 
 
-;; Author: Paul Kinnucan <paulk@mathworks.com>
+;; Author: Paul Kinnucan <pkinnucan@attbi.com>
 ;; Maintainer: Paul Kinnucan
 ;; Keywords: java, tools
 
-;; Copyright (C) 1997, 1998, 2001 Paul Kinnucan.
+;; Copyright (C) 1997, 1998, 2001, 2002 Paul Kinnucan.
 
 ;; GNU Emacs is free software; you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -30,9 +30,10 @@
  :type 'string)
 
 (defcustom jde-make-working-directory ""
-  "*Path of the working directory to use in 'make' build mode.
+  "*Path of the working directory to use in 'make' build mode. This
+string must end in a slash, for example, c:/foo/bar/ or ./  .
 If this string is empty, the 'make' build mode uses the current file
-location as its working directory"
+location as its working directory."
   :group 'jde-project
   :type 'string)
 
@@ -67,7 +68,12 @@ list of arguments entered in the minibuffer."
 
 ;;;###autoload
 (defun jde-make ()
-  "Run the JDE make program."
+  "Run the make program specified by `jde-make-program' with the
+command-line arguments specified by `jde-make-args'. If
+`jde-read-make-args' is nonnil, this command also prompts you to enter
+make arguments in the minibuffer and passes any arguments that you
+enter to the make program along with the arguments specified by
+`jde-make-args'."
   (interactive)
   (if jde-read-make-args
       (setq jde-interactive-make-args
@@ -103,26 +109,24 @@ list of arguments entered in the minibuffer."
       (save-some-buffers (not compilation-ask-about-save) nil))
     (compile-internal make-command "No more errors")))
 
-; (defun jde-make (args)
-;   "Run the JDE make program."
-;   (interactive
-;    (list (if (string= jde-make-args "")
-; 	     (read-from-minibuffer (concat jde-make-program " ")
-; 				   (nth 0 minibuffer-history))
-; 	   jde-make-args)))
-
-;   (compile 
-;    (concat
-;     jde-make-program
-;     " "
-;     (jde-run-make-arg-string
-;      (jde-run-parse-args args)))))
 
 (provide 'jde-make)
 
 ;; $Log: jde-make.el,v $
-;; Revision 1.3  2001/08/16 03:29:20  andyp
-;; Update to JDE 2.2.7.1
+;; Revision 1.5  2002/09/14 03:21:03  andyp
+;; sync to jde 2.2.9beta12
+;;
+;; Revision 1.12  2002/03/22 05:24:32  paulk
+;; Expanded documentation for the jde-make command.
+;;
+;; Revision 1.11  2001/07/16 13:39:33  paulk
+;; Added note to the doc for jde-make-working-directory that the path must end in a path separator.
+;;
+;; Revision 1.10  2001/05/31 04:00:50  paulk
+;; Backed out the previous change which was NOT a bug.
+;;
+;; Revision 1.9  2001/05/31 01:09:13  paulk
+;; Small bug fix. Thanks to Luis Miguel Hernanz Iglesias <luish@germinus.com>.
 ;;
 ;; Revision 1.8  2001/04/16 05:59:17  paulk
 ;; Normalize paths. Thanks to Nick Sieger.
